@@ -1,14 +1,13 @@
-from collections.abc import Sequence as AbstractSequence
 from enum import Enum
 from typing import (
     Any,
     Callable,
+    Collection,
     Dict,
     Generic,
     List,
     NamedTuple,
     Optional,
-    Sequence,
     TYPE_CHECKING,
     Type,
     TypeVar,
@@ -17,7 +16,7 @@ from typing import (
     overload,
 )
 
-from ..error import INVALID, InvalidType
+from ..error import GraphQLError
 from ..language import (
     EnumTypeDefinitionNode,
     EnumValueDefinitionNode,
@@ -41,18 +40,23 @@ from ..language import (
     UnionTypeDefinitionNode,
     UnionTypeExtensionNode,
     ValueNode,
+    print_ast,
 )
 from ..pyutils import (
     AwaitableOrValue,
     FrozenList,
     Path,
     cached_property,
+    did_you_mean,
     inspect,
+    is_collection,
     is_description,
+    suggestion_list,
+    Undefined,
 )
 from ..utilities.value_from_ast_untyped import value_from_ast_untyped
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
     from .schema import GraphQLSchema  # noqa: F401
 
 __all__ = [
@@ -161,7 +165,7 @@ class GraphQLWrappingType(GraphQLType, Generic[GT]):
 
     of_type: GT
 
-    def __init__(self, type_: GT) -> None:
+    def __init__(self, type_: GT):
         if not is_type(type_):
             raise TypeError(
                 f"Can only create a wrapper for a GraphQLType, but got: {type_}."
@@ -197,10 +201,10 @@ class GraphQLNamedType(GraphQLType):
     def __init__(
         self,
         name: str,
-        description: str = None,
-        extensions: Dict[str, Any] = None,
-        ast_node: TypeDefinitionNode = None,
-        extension_ast_nodes: Sequence[TypeExtensionNode] = None,
+        description: Optional[str] = None,
+        extensions: Optional[Dict[str, Any]] = None,
+        ast_node: Optional[TypeDefinitionNode] = None,
+        extension_ast_nodes: Optional[Collection[TypeExtensionNode]] = None,
     ) -> None:
         if not name:
             raise TypeError("Must provide name.")
@@ -216,12 +220,12 @@ class GraphQLNamedType(GraphQLType):
         if ast_node and not isinstance(ast_node, TypeDefinitionNode):
             raise TypeError(f"{name} AST node must be a TypeDefinitionNode.")
         if extension_ast_nodes:
-            if not isinstance(extension_ast_nodes, AbstractSequence) or not all(
+            if not is_collection(extension_ast_nodes) or not all(
                 isinstance(node, TypeExtensionNode) for node in extension_ast_nodes
             ):
                 raise TypeError(
                     f"{name} extension AST nodes must be specified"
-                    " as a sequence of TypeExtensionNode instances."
+                    " as a collection of TypeExtensionNode instances."
                 )
             if not isinstance(extension_ast_nodes, FrozenList):
                 extension_ast_nodes = FrozenList(extension_ast_nodes)
@@ -261,15 +265,15 @@ def assert_named_type(type_: Any) -> GraphQLNamedType:
 
 @overload
 def get_named_type(type_: None) -> None:
-    ...  # pragma: no cover
+    ...
 
 
-@overload  # noqa: F811 (pycqa/flake8#423)
+@overload
 def get_named_type(type_: GraphQLType) -> GraphQLNamedType:
-    ...  # pragma: no cover
+    ...
 
 
-def get_named_type(type_):  # noqa: F811
+def get_named_type(type_):
     """Unwrap possible wrapping type"""
     if type_:
         unwrapped_type = type_
@@ -321,13 +325,13 @@ class GraphQLScalarType(GraphQLNamedType):
     def __init__(
         self,
         name: str,
-        serialize: GraphQLScalarSerializer = None,
-        parse_value: GraphQLScalarValueParser = None,
-        parse_literal: GraphQLScalarLiteralParser = None,
-        description: str = None,
-        extensions: Dict[str, Any] = None,
-        ast_node: ScalarTypeDefinitionNode = None,
-        extension_ast_nodes: Sequence[ScalarTypeExtensionNode] = None,
+        serialize: Optional[GraphQLScalarSerializer] = None,
+        parse_value: Optional[GraphQLScalarValueParser] = None,
+        parse_literal: Optional[GraphQLScalarLiteralParser] = None,
+        description: Optional[str] = None,
+        extensions: Optional[Dict[str, Any]] = None,
+        ast_node: Optional[ScalarTypeDefinitionNode] = None,
+        extension_ast_nodes: Optional[Collection[ScalarTypeExtensionNode]] = None,
     ) -> None:
         super().__init__(
             name=name,
@@ -358,7 +362,7 @@ class GraphQLScalarType(GraphQLNamedType):
         ):
             raise TypeError(
                 f"{name} extension AST nodes must be specified"
-                " as a sequence of ScalarTypeExtensionNode instances."
+                " as a collection of ScalarTypeExtensionNode instances."
             )
         if serialize is not None:
             self.serialize = serialize  # type: ignore
@@ -391,7 +395,9 @@ class GraphQLScalarType(GraphQLNamedType):
         """
         return value
 
-    def parse_literal(self, node: ValueNode, _variables: Dict[str, Any] = None) -> Any:
+    def parse_literal(
+        self, node: ValueNode, _variables: Optional[Dict[str, Any]] = None
+    ) -> Any:
         """Parses an externally provided literal value to use as an input.
 
         This default method uses the parse_value method and should be replaced
@@ -443,13 +449,13 @@ class GraphQLField:
     def __init__(
         self,
         type_: "GraphQLOutputType",
-        args: GraphQLArgumentMap = None,
-        resolve: "GraphQLFieldResolver" = None,
-        subscribe: "GraphQLFieldResolver" = None,
-        description: str = None,
-        deprecation_reason: str = None,
-        extensions: Dict[str, Any] = None,
-        ast_node: FieldDefinitionNode = None,
+        args: Optional[GraphQLArgumentMap] = None,
+        resolve: Optional["GraphQLFieldResolver"] = None,
+        subscribe: Optional["GraphQLFieldResolver"] = None,
+        description: Optional[str] = None,
+        deprecation_reason: Optional[str] = None,
+        extensions: Optional[Dict[str, Any]] = None,
+        ast_node: Optional[FieldDefinitionNode] = None,
     ) -> None:
         if not is_output_type(type_):
             raise TypeError("Field type must be an output type.")
@@ -527,7 +533,7 @@ class GraphQLField:
 
     @property
     def is_deprecated(self) -> bool:
-        return bool(self.deprecation_reason)
+        return self.deprecation_reason is not None
 
 
 class GraphQLResolveInfo(NamedTuple):
@@ -551,6 +557,7 @@ class GraphQLResolveInfo(NamedTuple):
     operation: OperationDefinitionNode
     variable_values: Dict[str, Any]
     context: Any
+    is_awaitable: Callable[[Any], bool]
 
 
 # Note: Contrary to the Javascript implementation of GraphQLFieldResolver,
@@ -586,14 +593,14 @@ class GraphQLArgument:
     def __init__(
         self,
         type_: "GraphQLInputType",
-        default_value: Any = INVALID,
-        description: str = None,
-        out_name: str = None,
-        extensions: Dict[str, Any] = None,
-        ast_node: InputValueDefinitionNode = None,
+        default_value: Any = Undefined,
+        description: Optional[str] = None,
+        out_name: Optional[str] = None,
+        extensions: Optional[Dict[str, Any]] = None,
+        ast_node: Optional[InputValueDefinitionNode] = None,
     ) -> None:
         if not is_input_type(type_):
-            raise TypeError("Argument type must be a GraphQL input type.")
+            raise TypeError(f"Argument type must be a GraphQL input type.")
         if description is not None and not is_description(description):
             raise TypeError("Argument description must be a string.")
         if out_name is not None and not isinstance(out_name, str):
@@ -636,7 +643,7 @@ class GraphQLArgument:
 
 
 def is_required_argument(arg: GraphQLArgument) -> bool:
-    return is_non_null_type(arg.type) and arg.default_value is INVALID
+    return is_non_null_type(arg.type) and arg.default_value is Undefined
 
 
 T = TypeVar("T")
@@ -681,12 +688,12 @@ class GraphQLObjectType(GraphQLNamedType):
         self,
         name: str,
         fields: Thunk[GraphQLFieldMap],
-        interfaces: Thunk[Sequence["GraphQLInterfaceType"]] = None,
-        is_type_of: GraphQLIsTypeOfFn = None,
-        extensions: Dict[str, Any] = None,
-        description: str = None,
-        ast_node: ObjectTypeDefinitionNode = None,
-        extension_ast_nodes: Sequence[ObjectTypeExtensionNode] = None,
+        interfaces: Optional[Thunk[Collection["GraphQLInterfaceType"]]] = None,
+        is_type_of: Optional[GraphQLIsTypeOfFn] = None,
+        extensions: Optional[Dict[str, Any]] = None,
+        description: Optional[str] = None,
+        ast_node: Optional[ObjectTypeDefinitionNode] = None,
+        extension_ast_nodes: Optional[Collection[ObjectTypeExtensionNode]] = None,
     ) -> None:
         super().__init__(
             name=name,
@@ -707,7 +714,7 @@ class GraphQLObjectType(GraphQLNamedType):
         ):
             raise TypeError(
                 f"{name} extension AST nodes must be specified"
-                " as a sequence of ObjectTypeExtensionNode instances."
+                " as a collection of ObjectTypeExtensionNode instances."
             )
         self._fields = fields
         self._interfaces = interfaces
@@ -727,7 +734,7 @@ class GraphQLObjectType(GraphQLNamedType):
         try:
             fields = resolve_thunk(self._fields)
         except Exception as error:
-            raise TypeError(f"{self.name} fields cannot be resolved: {error}")
+            raise TypeError(f"{self.name} fields cannot be resolved. {error}")
         if not isinstance(fields, dict) or not all(
             isinstance(key, str) for key in fields
         ):
@@ -751,19 +758,19 @@ class GraphQLObjectType(GraphQLNamedType):
     def interfaces(self) -> List["GraphQLInterfaceType"]:
         """Get provided interfaces."""
         try:
-            interfaces: Sequence["GraphQLInterfaceType"] = resolve_thunk(
+            interfaces: Collection["GraphQLInterfaceType"] = resolve_thunk(
                 self._interfaces
             )
         except Exception as error:
-            raise TypeError(f"{self.name} interfaces cannot be resolved: {error}")
+            raise TypeError(f"{self.name} interfaces cannot be resolved. {error}")
         if interfaces is None:
             interfaces = []
-        elif not isinstance(interfaces, AbstractSequence) or not all(
+        elif not is_collection(interfaces) or not all(
             isinstance(value, GraphQLInterfaceType) for value in interfaces
         ):
             raise TypeError(
                 f"{self.name} interfaces must be specified"
-                " as a sequence of GraphQLInterfaceType instances."
+                " as a collection of GraphQLInterfaceType instances."
             )
         return list(interfaces)
 
@@ -800,12 +807,13 @@ class GraphQLInterfaceType(GraphQLNamedType):
     def __init__(
         self,
         name: str,
-        fields: Thunk[GraphQLFieldMap] = None,
-        resolve_type: GraphQLTypeResolver = None,
-        description: str = None,
-        extensions: Dict[str, Any] = None,
-        ast_node: InterfaceTypeDefinitionNode = None,
-        extension_ast_nodes: Sequence[InterfaceTypeExtensionNode] = None,
+        fields: Optional[Thunk[GraphQLFieldMap]] = None,
+        interfaces: Optional[Thunk[Collection["GraphQLInterfaceType"]]] = None,
+        resolve_type: Optional[GraphQLTypeResolver] = None,
+        description: Optional[str] = None,
+        extensions: Optional[Dict[str, Any]] = None,
+        ast_node: Optional[InterfaceTypeDefinitionNode] = None,
+        extension_ast_nodes: Optional[Collection[InterfaceTypeExtensionNode]] = None,
     ) -> None:
         super().__init__(
             name=name,
@@ -826,15 +834,17 @@ class GraphQLInterfaceType(GraphQLNamedType):
         ):
             raise TypeError(
                 f"{name} extension AST nodes must be specified"
-                " as a sequence of InterfaceTypeExtensionNode instances."
+                " as a collection of InterfaceTypeExtensionNode instances."
             )
         self._fields = fields
+        self._interfaces = interfaces
         self.resolve_type = resolve_type
 
     def to_kwargs(self) -> Dict[str, Any]:
         return dict(
             **super().to_kwargs(),
             fields=self.fields.copy(),
+            interfaces=self.interfaces.copy(),
             resolve_type=self.resolve_type,
         )
 
@@ -844,7 +854,7 @@ class GraphQLInterfaceType(GraphQLNamedType):
         try:
             fields = resolve_thunk(self._fields)
         except Exception as error:
-            raise TypeError(f"{self.name} fields cannot be resolved: {error}")
+            raise TypeError(f"{self.name} fields cannot be resolved. {error}")
         if not isinstance(fields, dict) or not all(
             isinstance(key, str) for key in fields
         ):
@@ -864,6 +874,26 @@ class GraphQLInterfaceType(GraphQLNamedType):
             for name, value in fields.items()
         }
 
+    @cached_property
+    def interfaces(self) -> List["GraphQLInterfaceType"]:
+        """Get provided interfaces."""
+        try:
+            interfaces: Collection["GraphQLInterfaceType"] = resolve_thunk(
+                self._interfaces
+            )
+        except Exception as error:
+            raise TypeError(f"{self.name} interfaces cannot be resolved. {error}")
+        if interfaces is None:
+            interfaces = []
+        elif not is_collection(interfaces) or not all(
+            isinstance(value, GraphQLInterfaceType) for value in interfaces
+        ):
+            raise TypeError(
+                f"{self.name} interfaces must be specified"
+                " as a collection of GraphQLInterfaceType instances."
+            )
+        return list(interfaces)
+
 
 def is_interface_type(type_: Any) -> bool:
     return isinstance(type_, GraphQLInterfaceType)
@@ -902,13 +932,17 @@ class GraphQLUnionType(GraphQLNamedType):
     def __init__(
         self,
         name,
-        types: Thunk[Sequence[GraphQLObjectType]],
-        resolve_type: GraphQLTypeResolver = None,
-        description: str = None,
-        extensions: Dict[str, Any] = None,
-        ast_node: UnionTypeDefinitionNode = None,
-        extension_ast_nodes: Sequence[UnionTypeExtensionNode] = None,
+        types: Thunk[Collection[GraphQLObjectType]],
+        resolve_type: Optional[GraphQLTypeResolver] = None,
+        description: Optional[str] = None,
+        extensions: Optional[Dict[str, Any]] = None,
+        ast_node: Optional[UnionTypeDefinitionNode] = None,
+        extension_ast_nodes: Optional[Collection[UnionTypeExtensionNode]] = None,
     ) -> None:
+        """
+
+        :rtype: object
+        """
         super().__init__(
             name=name,
             description=description,
@@ -928,7 +962,7 @@ class GraphQLUnionType(GraphQLNamedType):
         ):
             raise TypeError(
                 f"{name} extension AST nodes must be specified"
-                " as a sequence of UnionTypeExtensionNode instances."
+                " as a collection of UnionTypeExtensionNode instances."
             )
         self._types = types
         self.resolve_type = resolve_type
@@ -942,17 +976,17 @@ class GraphQLUnionType(GraphQLNamedType):
     def types(self) -> List[GraphQLObjectType]:
         """Get provided types."""
         try:
-            types: Sequence[GraphQLObjectType] = resolve_thunk(self._types)
+            types: Collection[GraphQLObjectType] = resolve_thunk(self._types)
         except Exception as error:
-            raise TypeError(f"{self.name} types cannot be resolved: {error}")
+            raise TypeError(f"{self.name} types cannot be resolved. {error}")
         if types is None:
             types = []
-        elif not isinstance(types, AbstractSequence) or not all(
+        elif not is_collection(types) or not all(
             isinstance(value, GraphQLObjectType) for value in types
         ):
             raise TypeError(
                 f"{self.name} types must be specified"
-                " as a sequence of GraphQLObjectType instances."
+                " as a collection of GraphQLObjectType instances."
             )
         return list(types)
 
@@ -1009,10 +1043,10 @@ class GraphQLEnumType(GraphQLNamedType):
         self,
         name: str,
         values: Union[GraphQLEnumValueMap, Dict[str, Any], Type[Enum]],
-        description: str = None,
-        extensions: Dict[str, Any] = None,
-        ast_node: EnumTypeDefinitionNode = None,
-        extension_ast_nodes: Sequence[EnumTypeExtensionNode] = None,
+        description: Optional[str] = None,
+        extensions: Optional[Dict[str, Any]] = None,
+        ast_node: Optional[EnumTypeDefinitionNode] = None,
+        extension_ast_nodes: Optional[Collection[EnumTypeExtensionNode]] = None,
     ) -> None:
         super().__init__(
             name=name,
@@ -1052,7 +1086,7 @@ class GraphQLEnumType(GraphQLNamedType):
         ):
             raise TypeError(
                 f"{name} extension AST nodes must be specified"
-                " as a sequence of EnumTypeExtensionNode instances."
+                " as a collection of EnumTypeExtensionNode instances."
             )
         self.values = values
 
@@ -1065,7 +1099,7 @@ class GraphQLEnumType(GraphQLNamedType):
         lookup: Dict[Any, str] = {}
         for name, enum_value in self.values.items():
             value = enum_value.value
-            if value is None:
+            if value is None or value is Undefined:
                 value = name
             try:
                 if value not in lookup:
@@ -1074,40 +1108,56 @@ class GraphQLEnumType(GraphQLNamedType):
                 pass  # ignore unhashable values
         return lookup
 
-    def serialize(self, value: Any) -> Union[str, None, InvalidType]:
+    def serialize(self, output_value: Any) -> str:
         try:
-            return self._value_lookup.get(value, INVALID)
-        except TypeError:  # unhashable value
+            return self._value_lookup[output_value]
+        except KeyError:  # hashable value not found
+            pass
+        except TypeError:  # unhashable value, we need to scan all values
             for enum_name, enum_value in self.values.items():
-                if enum_value.value == value:
+                if enum_value.value == output_value:
                     return enum_name
-        return INVALID
+        raise GraphQLError(
+            f"Enum '{self.name}' cannot represent value: {inspect(output_value)}"
+        )
 
-    def parse_value(self, value: str) -> Any:
-        if isinstance(value, str):
+    def parse_value(self, input_value: str) -> Any:
+        if isinstance(input_value, str):
             try:
-                enum_value = self.values[value]
+                enum_value = self.values[input_value]
             except KeyError:
-                return INVALID
-            if enum_value.value is None:
-                return value
+                raise GraphQLError(
+                    f"Value '{input_value}' does not exist in '{self.name}' enum."
+                    + did_you_mean_enum_value(self, input_value)
+                )
             return enum_value.value
-        return INVALID
+        value_str = inspect(input_value)
+        raise GraphQLError(
+            f"Enum '{self.name}' cannot represent non-string value: {value_str}."
+            + did_you_mean_enum_value(self, value_str)
+        )
 
     def parse_literal(
-        self, value_node: ValueNode, _variables: Dict[str, Any] = None
+        self, value_node: ValueNode, _variables: Optional[Dict[str, Any]] = None
     ) -> Any:
         # Note: variables will be resolved before calling this method.
         if isinstance(value_node, EnumValueNode):
-            value = value_node.value
             try:
-                enum_value = self.values[value]
+                enum_value = self.values[value_node.value]
             except KeyError:
-                return INVALID
-            if enum_value.value is None:
-                return value
+                value_str = print_ast(value_node)
+                raise GraphQLError(
+                    f"Value '{value_str}' does not exist in '{self.name}' enum."
+                    + did_you_mean_enum_value(self, value_str),
+                    value_node,
+                )
             return enum_value.value
-        return INVALID
+        value_str = print_ast(value_node)
+        raise GraphQLError(
+            f"Enum '{self.name}' cannot represent non-enum value: {value_str}."
+            + did_you_mean_enum_value(self, value_str),
+            value_node,
+        )
 
 
 def is_enum_type(type_: Any) -> bool:
@@ -1120,6 +1170,11 @@ def assert_enum_type(type_: Any) -> GraphQLEnumType:
     return cast(GraphQLEnumType, type_)
 
 
+def did_you_mean_enum_value(enum_type: GraphQLEnumType, unknown_value_str: str) -> str:
+    suggested_values = suggestion_list(unknown_value_str, enum_type.values)
+    return did_you_mean(suggested_values, "the enum value")
+
+
 class GraphQLEnumValue:
 
     value: Any
@@ -1131,10 +1186,10 @@ class GraphQLEnumValue:
     def __init__(
         self,
         value: Any = None,
-        description: str = None,
-        deprecation_reason: str = None,
-        extensions: Dict[str, Any] = None,
-        ast_node: EnumValueDefinitionNode = None,
+        description: Optional[str] = None,
+        deprecation_reason: Optional[str] = None,
+        extensions: Optional[Dict[str, Any]] = None,
+        ast_node: Optional[EnumValueDefinitionNode] = None,
     ) -> None:
         if description is not None and not is_description(description):
             raise TypeError("The description of the enum value must be a string.")
@@ -1177,7 +1232,7 @@ class GraphQLEnumValue:
 
     @property
     def is_deprecated(self) -> bool:
-        return bool(self.deprecation_reason)
+        return self.deprecation_reason is not None
 
 
 GraphQLInputFieldMap = Dict[str, "GraphQLInputField"]
@@ -1216,11 +1271,11 @@ class GraphQLInputObjectType(GraphQLNamedType):
         self,
         name: str,
         fields: Thunk[GraphQLInputFieldMap],
-        description: str = None,
-        out_type: GraphQLInputFieldOutType = None,
-        extensions: Dict[str, Any] = None,
-        ast_node: InputObjectTypeDefinitionNode = None,
-        extension_ast_nodes: Sequence[InputObjectTypeExtensionNode] = None,
+        description: Optional[str] = None,
+        out_type: Optional[GraphQLInputFieldOutType] = None,
+        extensions: Optional[Dict[str, Any]] = None,
+        ast_node: Optional[InputObjectTypeDefinitionNode] = None,
+        extension_ast_nodes: Optional[Collection[InputObjectTypeExtensionNode]] = None,
     ) -> None:
         super().__init__(
             name=name,
@@ -1241,7 +1296,7 @@ class GraphQLInputObjectType(GraphQLNamedType):
         ):
             raise TypeError(
                 f"{name} extension AST nodes must be specified"
-                " as a sequence of InputObjectTypeExtensionNode instances."
+                " as a collection of InputObjectTypeExtensionNode instances."
             )
         self._fields = fields
         if out_type is not None:
@@ -1270,7 +1325,7 @@ class GraphQLInputObjectType(GraphQLNamedType):
         try:
             fields = resolve_thunk(self._fields)
         except Exception as error:
-            raise TypeError(f"{self.name} fields cannot be resolved: {error}")
+            raise TypeError(f"{self.name} fields cannot be resolved. {error}")
         if not isinstance(fields, dict) or not all(
             isinstance(key, str) for key in fields
         ):
@@ -1317,14 +1372,14 @@ class GraphQLInputField:
     def __init__(
         self,
         type_: "GraphQLInputType",
-        default_value: Any = INVALID,
-        description: str = None,
-        out_name: str = None,
-        extensions: Dict[str, Any] = None,
-        ast_node: InputValueDefinitionNode = None,
+        default_value: Any = Undefined,
+        description: Optional[str] = None,
+        out_name: Optional[str] = None,
+        extensions: Optional[Dict[str, Any]] = None,
+        ast_node: Optional[InputValueDefinitionNode] = None,
     ) -> None:
         if not is_input_type(type_):
-            raise TypeError("Input field type must be a GraphQL input type.")
+            raise TypeError(f"Input field type must be a GraphQL input type.")
         if description is not None and not is_description(description):
             raise TypeError("Input field description must be a string.")
         if out_name is not None and not isinstance(out_name, str):
@@ -1367,7 +1422,7 @@ class GraphQLInputField:
 
 
 def is_required_input_field(field: GraphQLInputField) -> bool:
-    return is_non_null_type(field.type) and field.default_value is INVALID
+    return is_non_null_type(field.type) and field.default_value is Undefined
 
 
 # Wrapper types
@@ -1392,7 +1447,7 @@ class GraphQLList(Generic[GT], GraphQLWrappingType[GT]):
                 }
     """
 
-    def __init__(self, type_: GT) -> None:
+    def __init__(self, type_: GT):
         super().__init__(type_=type_)
 
     def __str__(self):
@@ -1432,7 +1487,7 @@ class GraphQLNonNull(GraphQLWrappingType[GNT], Generic[GNT]):
     Note: the enforcement of non-nullability occurs within the executor.
     """
 
-    def __init__(self, type_: GNT) -> None:
+    def __init__(self, type_: GNT):
         super().__init__(type_=type_)
         if isinstance(type_, GraphQLNonNull):
             raise TypeError(
@@ -1489,20 +1544,20 @@ def assert_nullable_type(type_: Any) -> GraphQLNullableType:
 
 @overload
 def get_nullable_type(type_: None) -> None:
-    ...  # pragma: no cover
+    ...
 
 
-@overload  # noqa: F811 (pycqa/flake8#423)
+@overload
 def get_nullable_type(type_: GraphQLNullableType) -> GraphQLNullableType:
-    ...  # pragma: no cover
+    ...
 
 
-@overload  # noqa: F811
+@overload
 def get_nullable_type(type_: GraphQLNonNull) -> GraphQLNullableType:
-    ...  # pragma: no cover
+    ...
 
 
-def get_nullable_type(type_):  # noqa: F811
+def get_nullable_type(type_):
     """Unwrap possible non-null type"""
     if is_non_null_type(type_):
         type_ = cast(GraphQLNonNull, type_)
