@@ -27,10 +27,7 @@ def test_validate_invalid_query(benchmark, big_schema_sdl):  # noqa: F811
             "message": "Cannot query field 'unknownField' on type 'Query'.",
             "locations": [(3, 11)],
         },
-        {
-            "message": "Unknown type 'unknownType'. Did you mean 'UnknownSignature'?",
-            "locations": [(4, 18)],
-        },
+        {"message": "Unknown type 'unknownType'.", "locations": [(4, 18)]},
         {"message": "Unknown fragment 'unknownFragment'.", "locations": [(6, 16)]},
         {"message": "Unknown type 'anotherUnknownType'.", "locations": [(10, 34)]},
         {"message": "Fragment 'TestFragment' is never used.", "locations": [(10, 9)]},
