@@ -4,7 +4,7 @@ from pytest import raises  # type: ignore
 
 from graphql.error import GraphQLSyntaxError
 from graphql.language import Lexer, Source, SourceLocation, Token, TokenKind
-from graphql.language.lexer import is_punctuator_token
+from graphql.language.lexer import is_punctuator_token_kind
 from graphql.pyutils import dedent, inspect
 
 
@@ -21,9 +21,10 @@ def lex_second(s: str) -> Token:
 
 def assert_syntax_error(text, message, location):
     with raises(GraphQLSyntaxError) as exc_info:
-        lex_one(text)
+        lex_second(text)
     error = exc_info.value
     assert error.message == f"Syntax Error: {message}"
+    assert error.description == message
     assert error.locations == [location]
 
 
@@ -60,6 +61,12 @@ def describe_lexer():
     def skips_whitespace_and_comments():
         token = lex_one("\n\n    foo\n\n\n")
         assert token == Token(TokenKind.NAME, 6, 9, 3, 5, None, "foo")
+        token = lex_one("\r\n\r\n  foo\r\n\r\n")
+        assert token == Token(TokenKind.NAME, 6, 9, 3, 3, None, "foo")
+        token = lex_one("\r\r  foo\r\r")
+        assert token == Token(TokenKind.NAME, 4, 7, 3, 3, None, "foo")
+        token = lex_one("\t\t  foo\t\t")
+        assert token == Token(TokenKind.NAME, 4, 7, 1, 5, None, "foo")
         token = lex_one("\n    #comment\n    foo#comment\n")
         assert token == Token(TokenKind.NAME, 18, 21, 3, 5, None, "foo")
         token = lex_one(",,,foo,,,")
@@ -194,8 +201,8 @@ def describe_lexer():
         assert lex_one('"""contains " quote"""') == Token(
             TokenKind.BLOCK_STRING, 0, 22, 1, 1, None, 'contains " quote'
         )
-        assert lex_one('"""contains \\""" triplequote"""') == Token(
-            TokenKind.BLOCK_STRING, 0, 31, 1, 1, None, 'contains """ triplequote'
+        assert lex_one('"""contains \\""" triple-quote"""') == Token(
+            TokenKind.BLOCK_STRING, 0, 32, 1, 1, None, 'contains """ triple-quote'
         )
         assert lex_one('"""multi\nline"""') == Token(
             TokenKind.BLOCK_STRING, 0, 16, 1, 1, None, "multi\nline"
@@ -330,6 +337,32 @@ def describe_lexer():
             "1.23.4", "Invalid number, expected digit but got: '.'.", (1, 5)
         )
 
+    def lex_does_not_allow_name_start_after_a_number():
+        assert_syntax_error(
+            "0xF1", "Invalid number, expected digit but got: 'x'.", (1, 2)
+        )
+        assert_syntax_error(
+            "0b10", "Invalid number, expected digit but got: 'b'.", (1, 2)
+        )
+        assert_syntax_error(
+            "123abc", "Invalid number, expected digit but got: 'a'.", (1, 4)
+        )
+        assert_syntax_error(
+            "1_1234", "Invalid number, expected digit but got: '_'.", (1, 2)
+        )
+        assert_syntax_error(
+            "1_1234", "Invalid number, expected digit but got: '_'.", (1, 2)
+        )
+        assert_syntax_error(
+            "1ß", "Cannot parse the unexpected character 'ß'.", (1, 2),
+        )
+        assert_syntax_error(
+            "1.23f", "Invalid number, expected digit but got: 'f'.", (1, 5)
+        )
+        assert_syntax_error(
+            "12ß", "Cannot parse the unexpected character 'ß'.", (1, 3),
+        )
+
     # noinspection PyArgumentEqualDefault
     def lexes_punctuation():
         assert lex_one("!") == Token(TokenKind.BANG, 0, 1, 1, 1, None, None)
@@ -404,27 +437,30 @@ def describe_lexer():
         ]
 
 
-def describe_is_punctuator_token():
+def describe_is_punctuator_token_kind():
+    def _is_punctuator_token(text: str) -> bool:
+        return is_punctuator_token_kind(lex_one(text).kind)
+
     def returns_true_for_punctuator_tokens():
-        assert is_punctuator_token(lex_one("!")) is True
-        assert is_punctuator_token(lex_one("$")) is True
-        assert is_punctuator_token(lex_one("&")) is True
-        assert is_punctuator_token(lex_one("(")) is True
-        assert is_punctuator_token(lex_one(")")) is True
-        assert is_punctuator_token(lex_one("...")) is True
-        assert is_punctuator_token(lex_one(":")) is True
-        assert is_punctuator_token(lex_one("=")) is True
-        assert is_punctuator_token(lex_one("@")) is True
-        assert is_punctuator_token(lex_one("[")) is True
-        assert is_punctuator_token(lex_one("]")) is True
-        assert is_punctuator_token(lex_one("{")) is True
-        assert is_punctuator_token(lex_one("|")) is True
-        assert is_punctuator_token(lex_one("}")) is True
+        assert _is_punctuator_token("!") is True
+        assert _is_punctuator_token("$") is True
+        assert _is_punctuator_token("&") is True
+        assert _is_punctuator_token("(") is True
+        assert _is_punctuator_token(")") is True
+        assert _is_punctuator_token("...") is True
+        assert _is_punctuator_token(":") is True
+        assert _is_punctuator_token("=") is True
+        assert _is_punctuator_token("@") is True
+        assert _is_punctuator_token("[") is True
+        assert _is_punctuator_token("]") is True
+        assert _is_punctuator_token("{") is True
+        assert _is_punctuator_token("|") is True
+        assert _is_punctuator_token("}") is True
 
     def returns_false_for_non_punctuator_tokens():
-        assert is_punctuator_token(lex_one("")) is False
-        assert is_punctuator_token(lex_one("name")) is False
-        assert is_punctuator_token(lex_one("1")) is False
-        assert is_punctuator_token(lex_one("3.14")) is False
-        assert is_punctuator_token(lex_one('"str"')) is False
-        assert is_punctuator_token(lex_one('"""str"""')) is False
+        assert _is_punctuator_token("") is False
+        assert _is_punctuator_token("name") is False
+        assert _is_punctuator_token("1") is False
+        assert _is_punctuator_token("3.14") is False
+        assert _is_punctuator_token('"str"') is False
+        assert _is_punctuator_token('"""str"""') is False
