@@ -20,7 +20,7 @@ def describe_printer_sdl_document():
             # noinspection PyTypeChecker
             print_ast(bad_ast)  # type: ignore
         msg = str(exc_info.value)
-        assert msg == "Not an AST Node: {'random': 'Data'}"
+        assert msg == "Not an AST Node: {'random': 'Data'}."
 
     # noinspection PyShadowingNames
     def does_not_alter_ast(kitchen_sink_sdl):  # noqa: F811
@@ -36,6 +36,7 @@ def describe_printer_sdl_document():
 
         assert printed == dedent(
             '''
+            """This is a description of the schema as a whole."""
             schema {
               query: QueryType
               mutation: MutationType
@@ -45,7 +46,7 @@ def describe_printer_sdl_document():
             This is a description
             of the `Foo` type.
             """
-            type Foo implements Bar & Baz {
+            type Foo implements Bar & Baz & Two {
               "Description of the `one` field."
               one: Type
               """This is a description of the `two` field."""
@@ -84,12 +85,18 @@ def describe_printer_sdl_document():
 
             interface UndefinedInterface
 
-            extend interface Bar {
+            extend interface Bar implements Two {
               two(argument: InputType!): Type
             }
 
             extend interface Bar @onInterface
 
+            interface Baz implements Bar & Two {
+              one: Type
+              two(argument: InputType!): Type
+              four(argument: String = "string"): String
+            }
+
             union Feed = Story | Article | Advert
 
             union AnnotatedUnion @onUnion = A | B
@@ -148,7 +155,10 @@ def describe_printer_sdl_document():
             extend input InputType @onInputObject
 
             """This is a description of the `@skip` directive"""
-            directive @skip(if: Boolean! @onArgumentDefinition) on FIELD | FRAGMENT_SPREAD | INLINE_FRAGMENT
+            directive @skip(
+              """This is a description of the `if` argument"""
+              if: Boolean! @onArgumentDefinition
+            ) on FIELD | FRAGMENT_SPREAD | INLINE_FRAGMENT
 
             directive @include(if: Boolean!) on FIELD | FRAGMENT_SPREAD | INLINE_FRAGMENT
 
