@@ -12,19 +12,19 @@ from graphql.type import (
     GraphQLString,
 )
 from graphql.utilities import get_introspection_query
-from graphql.validation.rules.provided_required_arguments import (
-    missing_field_arg_message,
-)
 
 
 def describe_introspection():
     def executes_an_introspection_query():
-        EmptySchema = GraphQLSchema(
-            GraphQLObjectType("QueryRoot", {"onlyField": GraphQLField(GraphQLString)})
+        schema = GraphQLSchema(
+            GraphQLObjectType("QueryRoot", {"onlyField": GraphQLField(GraphQLString)}),
+            description="Sample schema",
+        )
+        source = get_introspection_query(
+            descriptions=False, directive_is_repeatable=True
         )
 
-        query = get_introspection_query(descriptions=False)
-        result = graphql_sync(EmptySchema, query)
+        result = graphql_sync(schema=schema, source=source)
         assert result.errors is None
         assert result.data == {
             "__schema": {
@@ -62,10 +62,30 @@ def describe_introspection():
                         "enumValues": None,
                         "possibleTypes": None,
                     },
+                    {
+                        "kind": "SCALAR",
+                        "name": "Boolean",
+                        "fields": None,
+                        "inputFields": None,
+                        "interfaces": None,
+                        "enumValues": None,
+                        "possibleTypes": None,
+                    },
                     {
                         "kind": "OBJECT",
                         "name": "__Schema",
                         "fields": [
+                            {
+                                "name": "description",
+                                "args": [],
+                                "type": {
+                                    "kind": "SCALAR",
+                                    "name": "String",
+                                    "ofType": None,
+                                },
+                                "isDeprecated": False,
+                                "deprecationReason": None,
+                            },
                             {
                                 "name": "types",
                                 "args": [],
@@ -378,15 +398,6 @@ def describe_introspection():
                         ],
                         "possibleTypes": None,
                     },
-                    {
-                        "kind": "SCALAR",
-                        "name": "Boolean",
-                        "fields": None,
-                        "inputFields": None,
-                        "interfaces": None,
-                        "enumValues": None,
-                        "possibleTypes": None,
-                    },
                     {
                         "kind": "OBJECT",
                         "name": "__Field",
@@ -641,6 +652,21 @@ def describe_introspection():
                                 "isDeprecated": False,
                                 "deprecationReason": None,
                             },
+                            {
+                                "name": "isRepeatable",
+                                "args": [],
+                                "type": {
+                                    "kind": "NON_NULL",
+                                    "name": None,
+                                    "ofType": {
+                                        "kind": "SCALAR",
+                                        "name": "Boolean",
+                                        "ofType": None,
+                                    },
+                                },
+                                "isDeprecated": False,
+                                "deprecationReason": None,
+                            },
                             {
                                 "name": "locations",
                                 "args": [],
@@ -802,6 +828,7 @@ def describe_introspection():
                 "directives": [
                     {
                         "name": "include",
+                        "isRepeatable": False,
                         "locations": ["FIELD", "FRAGMENT_SPREAD", "INLINE_FRAGMENT"],
                         "args": [
                             {
@@ -821,6 +848,7 @@ def describe_introspection():
                     },
                     {
                         "name": "skip",
+                        "isRepeatable": False,
                         "locations": ["FIELD", "FRAGMENT_SPREAD", "INLINE_FRAGMENT"],
                         "args": [
                             {
@@ -840,6 +868,7 @@ def describe_introspection():
                     },
                     {
                         "name": "deprecated",
+                        "isRepeatable": False,
                         "locations": ["FIELD_DEFINITION", "ENUM_VALUE"],
                         "args": [
                             {
@@ -877,7 +906,7 @@ def describe_introspection():
         )
 
         schema = GraphQLSchema(TestType)
-        request = """
+        source = """
             {
               __type(name: "TestInputObject") {
                 kind
@@ -908,7 +937,7 @@ def describe_introspection():
             }
             """
 
-        assert graphql_sync(schema, request) == (
+        assert graphql_sync(schema=schema, source=source) == (
             {
                 "__type": {
                     "kind": "INPUT_OBJECT",
@@ -957,7 +986,7 @@ def describe_introspection():
         )
 
         schema = GraphQLSchema(TestType)
-        request = """
+        source = """
             {
               __type(name: "TestType") {
                 name
@@ -965,7 +994,10 @@ def describe_introspection():
             }
             """
 
-        assert graphql_sync(schema, request) == ({"__type": {"name": "TestType"}}, None)
+        assert graphql_sync(schema=schema, source=source) == (
+            {"__type": {"name": "TestType"}},
+            None,
+        )
 
     def identifies_deprecated_fields():
         TestType = GraphQLObjectType(
@@ -975,11 +1007,14 @@ def describe_introspection():
                 "deprecated": GraphQLField(
                     GraphQLString, deprecation_reason="Removed in 1.0"
                 ),
+                "deprecatedWithEmptyReason": GraphQLField(
+                    GraphQLString, deprecation_reason=""
+                ),
             },
         )
 
         schema = GraphQLSchema(TestType)
-        request = """
+        source = """
             {
               __type(name: "TestType") {
                 name
@@ -992,7 +1027,7 @@ def describe_introspection():
             }
             """
 
-        assert graphql_sync(schema, request) == (
+        assert graphql_sync(schema=schema, source=source) == (
             {
                 "__type": {
                     "name": "TestType",
@@ -1007,6 +1042,11 @@ def describe_introspection():
                             "isDeprecated": True,
                             "deprecationReason": "Removed in 1.0",
                         },
+                        {
+                            "name": "deprecatedWithEmptyReason",
+                            "isDeprecated": True,
+                            "deprecationReason": "",
+                        },
                     ],
                 }
             },
@@ -1025,7 +1065,7 @@ def describe_introspection():
         )
 
         schema = GraphQLSchema(TestType)
-        request = """
+        source = """
             {
               __type(name: "TestType") {
                 name
@@ -1042,7 +1082,7 @@ def describe_introspection():
             }
             """
 
-        assert graphql_sync(schema, request) == (
+        assert graphql_sync(schema=schema, source=source) == (
             {
                 "__type": {
                     "name": "TestType",
@@ -1058,16 +1098,16 @@ def describe_introspection():
         TestEnum = GraphQLEnumType(
             "TestEnum",
             {
-                "NONDEPRECATED": GraphQLEnumValue(0),
+                "NON_DEPRECATED": GraphQLEnumValue(0),
                 "DEPRECATED": GraphQLEnumValue(1, deprecation_reason="Removed in 1.0"),
-                "ALSONONDEPRECATED": GraphQLEnumValue(2),
+                "ALSO_NON_DEPRECATED": GraphQLEnumValue(2),
             },
         )
 
         TestType = GraphQLObjectType("TestType", {"testEnum": GraphQLField(TestEnum)})
 
         schema = GraphQLSchema(TestType)
-        request = """
+        source = """
             {
               __type(name: "TestEnum") {
                 name
@@ -1080,13 +1120,13 @@ def describe_introspection():
             }
             """
 
-        assert graphql_sync(schema, request) == (
+        assert graphql_sync(schema=schema, source=source) == (
             {
                 "__type": {
                     "name": "TestEnum",
                     "enumValues": [
                         {
-                            "name": "NONDEPRECATED",
+                            "name": "NON_DEPRECATED",
                             "isDeprecated": False,
                             "deprecationReason": None,
                         },
@@ -1096,7 +1136,7 @@ def describe_introspection():
                             "deprecationReason": "Removed in 1.0",
                         },
                         {
-                            "name": "ALSONONDEPRECATED",
+                            "name": "ALSO_NON_DEPRECATED",
                             "isDeprecated": False,
                             "deprecationReason": None,
                         },
@@ -1110,19 +1150,21 @@ def describe_introspection():
         TestEnum = GraphQLEnumType(
             "TestEnum",
             {
-                "NONDEPRECATED": GraphQLEnumValue(0),
+                "NON_DEPRECATED": GraphQLEnumValue(0),
                 "DEPRECATED": GraphQLEnumValue(1, deprecation_reason="Removed in 1.0"),
-                "ALSONONDEPRECATED": GraphQLEnumValue(2),
+                "DEPRECATED_WITH_EMPTY_REASON": GraphQLEnumValue(
+                    2, deprecation_reason=""
+                ),
+                "ALSO_NON_DEPRECATED": GraphQLEnumValue(3),
             },
         )
 
         TestType = GraphQLObjectType("TestType", {"testEnum": GraphQLField(TestEnum)})
 
         schema = GraphQLSchema(TestType)
-        request = """
+        source = """
             {
               __type(name: "TestEnum") {
-                  name
                 trueValues: enumValues(includeDeprecated: true) {
                   name
                 }
@@ -1136,22 +1178,22 @@ def describe_introspection():
             }
             """
 
-        assert graphql_sync(schema, request) == (
+        assert graphql_sync(schema=schema, source=source) == (
             {
                 "__type": {
-                    "name": "TestEnum",
                     "trueValues": [
-                        {"name": "NONDEPRECATED"},
+                        {"name": "NON_DEPRECATED"},
                         {"name": "DEPRECATED"},
-                        {"name": "ALSONONDEPRECATED"},
+                        {"name": "DEPRECATED_WITH_EMPTY_REASON"},
+                        {"name": "ALSO_NON_DEPRECATED"},
                     ],
                     "falseValues": [
-                        {"name": "NONDEPRECATED"},
-                        {"name": "ALSONONDEPRECATED"},
+                        {"name": "NON_DEPRECATED"},
+                        {"name": "ALSO_NON_DEPRECATED"},
                     ],
                     "omittedValues": [
-                        {"name": "NONDEPRECATED"},
-                        {"name": "ALSONONDEPRECATED"},
+                        {"name": "NON_DEPRECATED"},
+                        {"name": "ALSO_NON_DEPRECATED"},
                     ],
                 }
             },
@@ -1164,18 +1206,19 @@ def describe_introspection():
         )
 
         schema = GraphQLSchema(TestType)
-        request = """
+        source = """
             {
               __type {
                 name
               }
             }
             """
-        assert graphql_sync(schema, request) == (
+        assert graphql_sync(schema=schema, source=source) == (
             None,
             [
                 {
-                    "message": missing_field_arg_message("__type", "name", "String!"),
+                    "message": "Field '__type' argument 'name'"
+                    " of type 'String!' is required, but it was not provided.",
                     "locations": [(3, 15)],
                 }
             ],
@@ -1187,8 +1230,7 @@ def describe_introspection():
         )
 
         schema = GraphQLSchema(QueryRoot)
-
-        request = """
+        source = """
             {
               schemaType: __type(name: "__Schema") {
                 name,
@@ -1201,7 +1243,7 @@ def describe_introspection():
             }
             """
 
-        assert graphql_sync(schema, request) == (
+        assert graphql_sync(schema=schema, source=source) == (
             {
                 "schemaType": {
                     "name": "__Schema",
@@ -1210,6 +1252,7 @@ def describe_introspection():
                     " directives on the server, as well as the entry points"
                     " for query, mutation, and subscription operations.",
                     "fields": [
+                        {"name": "description", "description": None},
                         {
                             "name": "types",
                             "description": "A list of all types supported"
@@ -1247,7 +1290,7 @@ def describe_introspection():
         )
 
         schema = GraphQLSchema(QueryRoot)
-        request = """
+        source = """
             {
               typeKindType: __type(name: "__TypeKind") {
                 name,
@@ -1260,7 +1303,7 @@ def describe_introspection():
             }
             """
 
-        assert graphql_sync(schema, request) == (
+        assert graphql_sync(schema=schema, source=source) == (
             {
                 "typeKindType": {
                     "name": "__TypeKind",
@@ -1278,7 +1321,8 @@ def describe_introspection():
                         },
                         {
                             "description": "Indicates this type is an interface."
-                            " `fields` and `possibleTypes` are valid fields.",
+                            " `fields`, `interfaces`, and `possibleTypes`"
+                            " are valid fields.",
                             "name": "INTERFACE",
                         },
                         {
@@ -1318,13 +1362,9 @@ def describe_introspection():
         )
 
         schema = GraphQLSchema(query_root)
-        source = get_introspection_query()
+        source = get_introspection_query(directive_is_repeatable=True)
 
-        called_for_fields = set()
+        def field_resolver(_obj, info):
+            assert False, f"Called on {info.parent_type.name}.{info.field_name}"
 
-        def field_resolver(value, info):
-            called_for_fields.add(f"{info.parent_type.name}::{info.field_name}")
-            return value
-
-        graphql_sync(schema, source, field_resolver=field_resolver)
-        assert not called_for_fields
+        graphql_sync(schema=schema, source=source, field_resolver=field_resolver)
