@@ -1,7 +1,13 @@
 from pytest import raises  # type: ignore
 
-from graphql.language import DirectiveLocation, TypeDefinitionNode, TypeExtensionNode
-from graphql.pyutils import dedent
+from graphql.language import (
+    DirectiveLocation,
+    SchemaDefinitionNode,
+    SchemaExtensionNode,
+    TypeDefinitionNode,
+    TypeExtensionNode,
+)
+from graphql.pyutils import dedent, FrozenList
 from graphql.type import (
     GraphQLArgument,
     GraphQLBoolean,
@@ -17,6 +23,8 @@ from graphql.type import (
     GraphQLScalarType,
     GraphQLSchema,
     GraphQLString,
+    GraphQLType,
+    specified_directives,
 )
 from graphql.utilities import print_schema
 
@@ -84,7 +92,9 @@ def describe_type_system_schema():
             },
         )
 
-        schema = GraphQLSchema(BlogQuery, BlogMutation, BlogSubscription)
+        schema = GraphQLSchema(
+            BlogQuery, BlogMutation, BlogSubscription, description="Sample schema",
+        )
 
         kwargs = schema.to_kwargs()
         types = kwargs.pop("types")
@@ -93,15 +103,28 @@ def describe_type_system_schema():
             "query": BlogQuery,
             "mutation": BlogMutation,
             "subscription": BlogSubscription,
-            "directives": None,
-            "ast_node": None,
+            "directives": specified_directives,
+            "description": "Sample schema",
             "extensions": None,
-            "extension_ast_nodes": None,
+            "ast_node": None,
+            "extension_ast_nodes": [],
             "assume_valid": False,
         }
 
         assert print_schema(schema) == dedent(
-            """
+            '''
+            """Sample schema"""
+            schema {
+              query: Query
+              mutation: Mutation
+              subscription: Subscription
+            }
+
+            type Query {
+              article(id: String): Article
+              feed: [Article]
+            }
+
             type Article {
               id: String
               isPublished: Boolean
@@ -127,17 +150,27 @@ def describe_type_system_schema():
               writeArticle: Article
             }
 
-            type Query {
-              article(id: String): Article
-              feed: [Article]
-            }
-
             type Subscription {
               articleSubscribe(id: String): Article
             }
-            """
+            '''
         )
 
+    def freezes_the_specified_directives():
+        directives = [GraphQLDirective("SomeDirective", [])]
+        schema = GraphQLSchema(directives=directives)
+        assert isinstance(schema.directives, FrozenList)
+        assert schema.directives == directives
+        directives = schema.directives
+        schema = GraphQLSchema(directives=directives)
+        assert schema.directives is directives
+
+    def rejects_a_schema_with_incorrectly_typed_description():
+        with raises(TypeError) as exc_info:
+            # noinspection PyTypeChecker
+            GraphQLSchema(description=[])  # type: ignore
+        assert str(exc_info.value) == "Schema description must be a string."
+
     def describe_type_map():
         def includes_interface_possible_types_in_the_type_map():
             SomeInterface = GraphQLInterfaceType("SomeInterface", {})
@@ -153,18 +186,20 @@ def describe_type_system_schema():
             assert schema.type_map["SomeInterface"] is SomeInterface
             assert schema.type_map["SomeSubtype"] is SomeSubtype
 
+            assert schema.is_sub_type(SomeInterface, SomeSubtype) is True
+            assert schema.is_possible_type(SomeInterface, SomeSubtype) is True
+
         def includes_interfaces_thunk_subtypes_in_the_type_map():
-            SomeInterface = GraphQLInterfaceType("SomeInterface", {})
+            AnotherInterface = GraphQLInterfaceType("AnotherInterface", {})
+            SomeInterface = GraphQLInterfaceType(
+                "SomeInterface", {}, interfaces=lambda: [AnotherInterface]
+            )
             SomeSubtype = GraphQLObjectType(
                 "SomeSubtype", {}, interfaces=lambda: [SomeInterface]
             )
-            schema = GraphQLSchema(
-                query=GraphQLObjectType(
-                    "Query", {"iface": GraphQLField(SomeInterface)}
-                ),
-                types=[SomeSubtype],
-            )
+            schema = GraphQLSchema(types=[SomeSubtype],)
             assert schema.type_map["SomeInterface"] is SomeInterface
+            assert schema.type_map["AnotherInterface"] is AnotherInterface
             assert schema.type_map["SomeSubtype"] is SomeSubtype
 
         def includes_nested_input_objects_in_the_map():
@@ -209,32 +244,46 @@ def describe_type_system_schema():
             assert "Foo" in schema.type_map
             assert "Bar" in schema.type_map
 
-    def describe_type_map_reducer():
-        def allows_overriding_the_type_map_reducers():
-            foo_type = GraphQLObjectType("Foo", {"bar": GraphQLField(GraphQLString)})
-            query_type = GraphQLObjectType("Query", {"foo": GraphQLField(foo_type)})
-            baz_directive = GraphQLDirective("Baz", [])
+    def preserves_the_order_of_user_provided_types():
+        a_type = GraphQLObjectType(
+            "A", {"sub": GraphQLField(GraphQLScalarType("ASub"))}
+        )
+        z_type = GraphQLObjectType(
+            "Z", {"sub": GraphQLField(GraphQLScalarType("ZSub"))}
+        )
+        query_type = GraphQLObjectType(
+            "Query",
+            {
+                "a": GraphQLField(a_type),
+                "z": GraphQLField(z_type),
+                "sub": GraphQLField(GraphQLScalarType("QuerySub")),
+            },
+        )
+        schema = GraphQLSchema(query_type, types=[z_type, query_type, a_type])
 
-            log_types = []
-            log_directives = []
+        type_names = list(schema.type_map)
+        assert type_names == [
+            "Z",
+            "ZSub",
+            "Query",
+            "QuerySub",
+            "A",
+            "ASub",
+            "Boolean",
+            "String",
+            "__Schema",
+            "__Type",
+            "__TypeKind",
+            "__Field",
+            "__InputValue",
+            "__EnumValue",
+            "__Directive",
+            "__DirectiveLocation",
+        ]
 
-            class CustomGraphQLSchema(GraphQLSchema):
-                def type_map_reducer(self, map_, type_):
-                    log_types.append(type_)
-                    return super().type_map_reducer(map_, type_)
-
-                def type_map_directive_reducer(self, map_, directive):
-                    log_directives.append(directive)
-                    return super().type_map_directive_reducer(map_, directive)
-
-            schema = CustomGraphQLSchema(query_type, directives=[baz_directive])
-            assert schema.type_map["Query"] == query_type
-            assert schema.type_map["Foo"] == foo_type
-            assert schema.directives == [baz_directive]
-            assert query_type in log_types
-            assert foo_type in log_types
-            assert GraphQLString in log_types
-            assert log_directives == [baz_directive]
+        # Also check that this order is stable
+        copy_schema = GraphQLSchema(**schema.to_kwargs())
+        assert list(copy_schema.type_map) == type_names
 
     def describe_validity():
         def describe_when_not_assumed_valid():
@@ -243,13 +292,35 @@ def describe_type_system_schema():
                 assert GraphQLSchema(assume_valid=False).validation_errors is None
 
             def checks_the_configuration_for_mistakes():
+                def query():
+                    pass
+
                 with raises(Exception):
                     # noinspection PyTypeChecker
-                    GraphQLSchema(lambda: None)  # type: ignore
+                    GraphQLSchema(query)  # type: ignore
                 with raises(Exception):
-                    GraphQLSchema(types={})  # type: ignore
+                    GraphQLSchema(types={})
                 with raises(Exception):
-                    GraphQLSchema(directives={})  # type: ignore
+                    GraphQLSchema(directives={})
+
+            def check_that_query_mutation_and_subscription_are_graphql_types():
+                directive = GraphQLDirective("foo", [])
+                with raises(TypeError) as exc_info:
+                    # noinspection PyTypeChecker
+                    GraphQLSchema(query=directive)  # type: ignore
+                assert str(exc_info.value) == "Expected query to be a GraphQL type."
+                with raises(TypeError) as exc_info:
+                    # noinspection PyTypeChecker
+                    GraphQLSchema(mutation=directive)  # type: ignore
+                assert str(exc_info.value) == (
+                    "Expected mutation to be a GraphQL type."
+                )
+                with raises(TypeError) as exc_info:
+                    # noinspection PyTypeChecker
+                    GraphQLSchema(subscription=directive)  # type: ignore
+                assert str(exc_info.value) == (
+                    "Expected subscription to be a GraphQL type."
+                )
 
     def describe_a_schema_must_contain_uniquely_named_types():
         def rejects_a_schema_which_redefines_a_built_in_type():
@@ -268,7 +339,18 @@ def describe_type_system_schema():
             msg = str(exc_info.value)
             assert msg == (
                 "Schema must contain uniquely named types"
-                " but contains multiple types named 'String'."
+                f" but contains multiple types named 'String'."
+            )
+
+        def rejects_a_schema_when_a_provided_type_has_no_name():
+            query = GraphQLObjectType("Query", {"foo": GraphQLField(GraphQLString)})
+            types = [GraphQLType(), query, GraphQLType()]
+
+            with raises(TypeError) as exc_info:
+                GraphQLSchema(query, types=types)  # type: ignore
+            msg = str(exc_info.value)
+            assert msg == (
+                "One of the provided types for building the Schema is missing a name."
             )
 
         def rejects_a_schema_which_defines_an_object_twice():
@@ -282,7 +364,7 @@ def describe_type_system_schema():
             msg = str(exc_info.value)
             assert msg == (
                 "Schema must contain uniquely named types"
-                " but contains multiple types named 'SameName'."
+                f" but contains multiple types named 'SameName'."
             )
 
         def rejects_a_schema_which_defines_fields_with_conflicting_types():
@@ -300,7 +382,7 @@ def describe_type_system_schema():
             msg = str(exc_info.value)
             assert msg == (
                 "Schema must contain uniquely named types"
-                " but contains multiple types named 'SameName'."
+                f" but contains multiple types named 'SameName'."
             )
 
         def describe_when_assumed_valid():
@@ -309,6 +391,26 @@ def describe_type_system_schema():
                 assert GraphQLSchema(assume_valid=True).validation_errors == []
 
     def describe_ast_nodes():
+        def accepts_a_scalar_type_with_ast_node_and_extension_ast_nodes():
+            ast_node = SchemaDefinitionNode()
+            extension_ast_nodes = [SchemaExtensionNode()]
+            schema = GraphQLSchema(
+                GraphQLObjectType("Query", {}),
+                ast_node=ast_node,
+                extension_ast_nodes=extension_ast_nodes,
+            )
+            assert schema.ast_node is ast_node
+            assert isinstance(schema.extension_ast_nodes, FrozenList)
+            assert schema.extension_ast_nodes == extension_ast_nodes
+            extension_ast_nodes = schema.extension_ast_nodes
+            schema = GraphQLSchema(
+                GraphQLObjectType("Query", {}),
+                ast_node=None,
+                extension_ast_nodes=extension_ast_nodes,
+            )
+            assert schema.ast_node is None
+            assert schema.extension_ast_nodes is extension_ast_nodes
+
         def rejects_a_schema_with_an_incorrect_ast_node():
             with raises(TypeError) as exc_info:
                 # noinspection PyTypeChecker
@@ -328,5 +430,5 @@ def describe_type_system_schema():
                 )
             assert str(exc_info.value) == (
                 "Schema extension AST nodes must be specified"
-                " as a sequence of SchemaExtensionNode instances."
+                " as a collection of SchemaExtensionNode instances."
             )
