@@ -5,6 +5,9 @@ from graphql.utilities import assert_valid_name
 
 
 def describe_assert_valid_name():
+    def pass_through_valid_name():
+        assert assert_valid_name("_ValidName123") == "_ValidName123"
+
     def throws_for_use_of_leading_double_underscore():
         with raises(GraphQLError) as exc_info:
             assert assert_valid_name("__bad")
@@ -19,7 +22,7 @@ def describe_assert_valid_name():
             # noinspection PyTypeChecker
             assert_valid_name({})  # type: ignore
         msg = str(exc_info.value)
-        assert msg == "Expected string"
+        assert msg == "Expected name to be a string."
 
     def throws_for_names_with_invalid_characters():
         with raises(GraphQLError, match="Names must match"):
