@@ -33,6 +33,35 @@ def describe_find_breaking_changes():
         ]
         assert find_breaking_changes(old_schema, old_schema) == []
 
+    def should_detect_if_a_standard_scalar_was_removed():
+        old_schema = build_schema(
+            """
+            type Query {
+              foo: Float
+            }
+            """
+        )
+
+        new_schema = build_schema(
+            """
+            type Query {
+              foo: String
+            }
+            """
+        )
+
+        assert find_breaking_changes(old_schema, new_schema) == [
+            (
+                BreakingChangeType.TYPE_REMOVED,
+                "Standard scalar Float was removed"
+                " because it is not referenced anymore.",
+            ),
+            (
+                BreakingChangeType.FIELD_CHANGED_KIND,
+                "Query.foo changed type from Float to String.",
+            ),
+        ]
+
     def should_detect_if_a_type_changed_its_type():
         old_schema = build_schema(
             """
@@ -573,11 +602,35 @@ def describe_find_breaking_changes():
 
         assert find_breaking_changes(old_schema, new_schema) == [
             (
-                BreakingChangeType.INTERFACE_REMOVED_FROM_OBJECT,
+                BreakingChangeType.IMPLEMENTED_INTERFACE_REMOVED,
                 "Type1 no longer implements interface Interface1.",
             )
         ]
 
+    def should_detect_intrefaces_removed_from_interfaces():
+        old_schema = build_schema(
+            """
+            interface Interface1
+
+            interface Interface2 implements Interface1
+            """
+        )
+
+        new_schema = build_schema(
+            """
+            interface Interface1
+
+            interface Interface2
+            """
+        )
+
+        assert find_breaking_changes(old_schema, new_schema) == [
+            (
+                BreakingChangeType.IMPLEMENTED_INTERFACE_REMOVED,
+                "Interface2 no longer implements interface Interface1.",
+            )
+        ]
+
     def should_ignore_changes_in_order_of_interfaces():
         old_schema = build_schema(
             """
@@ -608,10 +661,12 @@ def describe_find_breaking_changes():
 
             directive @NonNullDirectiveAdded on FIELD_DEFINITION
 
+            directive @DirectiveThatWasRepeatable repeatable on FIELD_DEFINITION
+
             directive @DirectiveName on FIELD_DEFINITION | QUERY
 
             type ArgThatChanges {
-                field1(id: Int): String
+                field1(id: Float): String
             }
 
             enum EnumTypeThatLosesAValue {
@@ -644,6 +699,8 @@ def describe_find_breaking_changes():
 
             directive @NonNullDirectiveAdded(arg1: Boolean!) on FIELD_DEFINITION
 
+            directive @DirectiveThatWasRepeatable on FIELD_DEFINITION
+
             directive @DirectiveName on FIELD_DEFINITION
 
             type ArgThatChanges {
@@ -672,18 +729,22 @@ def describe_find_breaking_changes():
         )
 
         assert find_breaking_changes(old_schema, new_schema) == [
-            (BreakingChangeType.TYPE_REMOVED, "Int was removed."),
+            (
+                BreakingChangeType.TYPE_REMOVED,
+                "Standard scalar Float was removed"
+                " because it is not referenced anymore.",
+            ),
             (BreakingChangeType.TYPE_REMOVED, "TypeThatGetsRemoved was removed."),
             (
                 BreakingChangeType.ARG_CHANGED_KIND,
-                "ArgThatChanges.field1 arg id has changed type from Int to String.",
+                "ArgThatChanges.field1 arg id has changed type from Float to String.",
             ),
             (
                 BreakingChangeType.VALUE_REMOVED_FROM_ENUM,
                 "VALUE0 was removed from enum type EnumTypeThatLosesAValue.",
             ),
             (
-                BreakingChangeType.INTERFACE_REMOVED_FROM_OBJECT,
+                BreakingChangeType.IMPLEMENTED_INTERFACE_REMOVED,
                 "TypeThatLoosesInterface1 no longer implements interface Interface1.",
             ),
             (
@@ -716,6 +777,10 @@ def describe_find_breaking_changes():
                 BreakingChangeType.REQUIRED_DIRECTIVE_ARG_ADDED,
                 "A required arg arg1 on directive NonNullDirectiveAdded was added.",
             ),
+            (
+                BreakingChangeType.DIRECTIVE_REPEATABLE_REMOVED,
+                "Repeatable flag was removed from DirectiveThatWasRepeatable.",
+            ),
             (
                 BreakingChangeType.DIRECTIVE_LOCATION_REMOVED,
                 "QUERY was removed from DirectiveName.",
@@ -801,6 +866,26 @@ def describe_find_breaking_changes():
             )
         ]
 
+    def should_detect_removal_of_repeatable_flag():
+        old_schema = build_schema(
+            """
+            directive @DirectiveName repeatable on OBJECT
+            """
+        )
+
+        new_schema = build_schema(
+            """
+            directive @DirectiveName on OBJECT
+            """
+        )
+
+        assert find_breaking_changes(old_schema, new_schema) == [
+            (
+                BreakingChangeType.DIRECTIVE_REPEATABLE_REMOVED,
+                "Repeatable flag was removed from DirectiveName.",
+            )
+        ]
+
     def should_detect_locations_removed_from_a_directive():
         old_schema = build_schema(
             """
@@ -1019,11 +1104,37 @@ def describe_find_dangerous_changes():
 
         assert find_dangerous_changes(old_schema, new_schema) == [
             (
-                DangerousChangeType.INTERFACE_ADDED_TO_OBJECT,
+                DangerousChangeType.IMPLEMENTED_INTERFACE_ADDED,
                 "NewInterface added to interfaces implemented by Type1.",
             )
         ]
 
+    def should_detect_interfaces_added_to_interfaces():
+        old_schema = build_schema(
+            """
+            interface OldInterface
+            interface NewInterface
+
+            interface Interface1 implements OldInterface
+            """
+        )
+
+        new_schema = build_schema(
+            """
+            interface OldInterface
+            interface NewInterface
+
+            interface Interface1 implements OldInterface & NewInterface
+            """
+        )
+
+        assert find_dangerous_changes(old_schema, new_schema) == [
+            (
+                DangerousChangeType.IMPLEMENTED_INTERFACE_ADDED,
+                "NewInterface added to interfaces implemented by Interface1.",
+            )
+        ]
+
     def should_detect_if_a_type_was_added_to_a_union_type():
         old_schema = build_schema(
             """
@@ -1127,7 +1238,7 @@ def describe_find_dangerous_changes():
                 ' from "test" to "Test".',
             ),
             (
-                DangerousChangeType.INTERFACE_ADDED_TO_OBJECT,
+                DangerousChangeType.IMPLEMENTED_INTERFACE_ADDED,
                 "Interface1 added to interfaces implemented"
                 " by TypeThatGainsInterface1.",
             ),
